==> pointpos_api-0.0.5.tar.gz: test/role_permission_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for RolePermission
void main() {
    var instance = new RolePermission();

  group('test RolePermission', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // num priorityRank (default value: null)
    test('to test the property `priorityRank`', () async {
      // TODO
    });

    // String menu (default value: null)
    test('to test the property `menu`', () async {
      // TODO
    });

    // String menuName (default value: null)
    test('to test the property `menuName`', () async {
      // TODO
    });

    // String access (default value: null)
    test('to test the property `access`', () async {
      // TODO
    });

    // bool pinRequired (default value: null)
    test('to test the property `pinRequired`', () async {
      // TODO
    });

    // bool mobileSupported (default value: null)
    test('to test the property `mobileSupported`', () async {
      // TODO
    });

    // bool usable (default value: null)
    test('to test the property `usable`', () async {
      // TODO
    });

    // List<String> urls (default value: [])
    test('to test the property `urls`', () async {
      // TODO
    });

    // String subMenu (default value: null)
    test('to test the property `subMenu`', () async {
      // TODO
    });

    // String subMenuName (default value: null)
    test('to test the property `subMenuName`', () async {
      // TODO
    });

    // bool isAllowedForPointPay (default value: null)
    test('to test the property `isAllowedForPointPay`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.0.13.tar.gz: test/role_permission_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for RolePermission
void main() {
  var instance = new RolePermission();

  group('test RolePermission', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // num priorityRank (default value: null)
    test('to test the property `priorityRank`', () async {
      // TODO
    });

    // String menu (default value: null)
    test('to test the property `menu`', () async {
      // TODO
    });

    // String menuName (default value: null)
    test('to test the property `menuName`', () async {
      // TODO
    });

    // String access (default value: null)
    test('to test the property `access`', () async {
      // TODO
    });

    // bool pinRequired (default value: null)
    test('to test the property `pinRequired`', () async {
      // TODO
    });

    // bool mobileSupported (default value: null)
    test('to test the property `mobileSupported`', () async {
      // TODO
    });

    // bool usable (default value: null)
    test('to test the property `usable`', () async {
      // TODO
    });

    // List<String> urls (default value: const [])
    test('to test the property `urls`', () async {
      // TODO
    });

    // String subMenu (default value: null)
    test('to test the property `subMenu`', () async {
      // TODO
    });

    // String subMenuName (default value: null)
    test('to test the property `subMenuName`', () async {
      // TODO
    });

    // bool isAllowedForPointPay (default value: null)
    test('to test the property `isAllowedForPointPay`', () async {
      // TODO
    });


  });

}
